#!/bin/bash

# This script configures things related to BV4627f relayboard
# Argo Ellisson 2014, BashPi.org, usage licence: GNU General Public License (GPL) Version 3
# version 1.2

if [ "$(id -u)" -ne "0" ] ; then
    echo "This script must be executed with root privileges."
    exit 1
fi

# change curent directory to script location
cd $(dirname $0)

# include functions
. ./files/functions.sh

# user homedir backup location
HOMEBACKUP="./files/relay_homedir"
# relay user/group name - if you change it, check all scripts!
USER="relay"
# relay udev file name
UDEV="99-relay.rules"

usage() {
   echo "THIS script may screw up some existing configuration in your system, please check the script if you care"
   echo "f.e. it will overwrite scripts in ${USER} user homedir if they already exist"
   echo "to avoid accidental running please use following to apply configuration:"
   echo "USAGE: configure.sh configure"
   echo "must be run as root user either directly or using sudo"
   cd - > /dev/null
   exit 1
}

case "$1" in
        configure)  

        echo "seting up user"
        add_systemuser ${USER}
        USERHOME=`get_homedir ${USER}`
        rsync -av ${HOMEBACKUP}/* ${USERHOME}
        chown ${USER}:${USER} ${USERHOME}/*
        chmod 700 ${USERHOME}
        chmod 700 ${USERHOME}/relay*.sh

        # udev rules are here instead of separate file as this way its easier to change scripts locations and users
        echo "seting up udev rules for relayboard"
        echo "# rule for FT232. creates symlink serialrelay under dev which is used later and runs monitoring script" > /etc/udev/rules.d/${UDEV}
        echo "# Bus 001 Device 013: ID 0403:6001 Future Technology Devices International, Ltd FT232 USB-Serial (UART) IC" >> /etc/udev/rules.d/${UDEV}
        echo "ACTION==\"add\", ATTRS{idVendor}==\"0403\", ATTRS{idProduct}==\"6001\", OWNER=\"${USER}\", GROUP=\"${USER}\", MODE=\"0660\", SYMLINK+=\"serialrelay_%s{serial}\", RUN+=\"/bin/su - ${USER} -c '${USERHOME}/relay_monitor.sh &'\"" >> /etc/udev/rules.d/${UDEV}
        echo "ACTION==\"remove\", KERNEL==\"ttyUSB*\", RUN+=\"/bin/su - ${USER} -c '${USERHOME}/relay_monitor.sh restart &'\"" >> /etc/udev/rules.d/${UDEV}
        udevadm control --reload-rules

        # importing crontab
        echo "seting up crontab"
        crontab -u ${USER} ./files/relay_crontab

        # copy sudo rules
        echo "seting up sudo rules"
        cp ./files/relay_sudoers /etc/sudoers.d/
        chmod 440 /etc/sudoers.d/relay_sudoers

        echo "configured! Please reboot to make sure udev rules and automatic startup work correctly."

        ;;
        *) echo "incorrect usage"
        usage
        ;;
esac

cd - > /dev/null

exit 0
