# this file contains some useful bash functions
# Argo Ellisson 2014, BashPi.org, usage licence: GNU General Public License (GPL) Version 3
# version 1.0

# tries to install a package to debian-based distro
try_install() {
	dpkg -l "${1}" | grep -q ^ii && return 1
	# or use following to check
	#dpkg-query -W -f='${Status}\n' packagename |grep "install ok installed" 
	
	apt-get update
	apt-get -y install "$@"
	apt-get clean
	return 0
}

# adds entries to crontab 
add_crontab() {

	# crontab file
	CRONTAB="/var/spool/cron/crontabs/${1}"

	# if does not exist, create
	[[ -f ${CRONTAB} ]] || touch ${CRONTAB} && chown ${1} ${CRONTAB}
	
	# crontab -u username -l does not do the trick with comment lines
        if [ `fgrep "${2}" ${CRONTAB} |wc -l` -lt 1 ];then
                echo "${2}" >> ${CRONTAB}
        fi
}

# adds entries to rc.local
add_rc.local() {
        if [ `grep "^${1}" /etc/rc.local |wc -l` -lt 1 ];then
                echo "${1}" >> /etc/rc.local
        fi
}

# adds entries to modules
add_modules() {
        if [ `grep "^${1}" /etc/modules |wc -l` -lt 1 ];then
                echo "${1}" >> /etc/modules
        fi
}

# adds entries to inittab
add_inittab() {
        if [ `grep "^${1}" /etc/inittab |wc -l` -lt 1 ];then
                echo "${1}" >> /etc/inittab
        fi
}

# comments out - adds hash symbol to beginning of the line
comment_line() {
	sed -i -e "/^${1}/s/^/#/" ${2}
}

# removes line from file
delete_line() {
        sed -i -e "/^${1}/d" ${2}
}

# creates system user
add_systemuser() {
        useradd -r -m ${1}
}

# gets user homedir
get_homedir() {
       getent passwd ${1} |cut -d':' -f6
}
