#!/bin/bash

# This script is used to monitor relay-board services and start them if needed
# Argo Ellisson 2014, BashPi.org, usage licence: GNU General Public License (GPL) Version 3
# version 1.2

# First check is some other monitoring process already running and exit if it is
pidof -x -o $$ relay_monitor.sh >& /dev/null && exit 0

# functions

# gets user homedir
get_homedir() {
       getent passwd ${1} |cut -d':' -f6
}

# relay user
USER="relay"
USERHOME=`get_homedir ${USER}`

# if restart parameter is added, restarts all services no matter what the status
# UDEV runs it when device is removed
if [ $# -eq 1 -a "${1}" = "restart" ]; then
        echo "restarting all processes"
        RESTART=1
        pkill -f relay_service.sh
        pkill -f commands.lst
        rm -f /dev/shm/*commands.lst >& /dev/null
        sleep 5
fi

# FOR CYCLE to check processes for each board found

for SERIALDEVICE in `ls /dev/serialrelay_* 2>/dev/null`; do 

        echo "Checking ${SERIALDEVICE} processes"

        DEVNAME=`basename ${SERIALDEVICE}`
        SERIAL=`echo ${DEVNAME}|cut -d'_' -f2`

        # check both processes 
        SERVICE=`ps -fu ${USER} | grep "relay_service.sh ${DEVNAME}"  | grep -v grep |wc -l`
        TAIL=`ps -fu ${USER} | grep "tail -f /dev/shm/${DEVNAME}_commands.lst" | grep -v grep |wc -l`

        if [ ${SERVICE} -eq 0 -o ${TAIL} -eq 0 ];then

                #killing all scripts what may be still running
                pkill -f ${DEVNAME}
                sleep 5

                ${USERHOME}/relay_service.sh ${DEVNAME} &

                # there is sleep in service script so this will compensate!
                sleep 10

                # now everything should either still run or was just started up
                # check again and echo results

                SERVICE=`ps -fu ${USER} | grep "relay_service.sh ${DEVNAME}"  | grep -v grep |wc -l`
                TAIL=`ps -fu ${USER} | grep "tail -f /dev/shm/${DEVNAME}_commands.lst" | grep -v grep |wc -l`

                if [ ${SERVICE} -eq 0 -o ${TAIL} -eq 0 ];then

                        echo "Board ${SERIAL} not working"

                else 

                        echo "Board ${SERIAL} ok"

                fi

        else                                                                                                                                                                                                                                                                         
                # already ok                                                                                                                                                                               
                echo "Board ${SERIAL} ok"
                                                                                                                                                                                                                                                                             
        fi

done

exit 0
